complex_tensor64

Macro complex_tensor64 

complex_tensor64!() { /* proc-macro */ }
Creates a 64-bit complex tensor from nested brackets. Complex numbers can be created using j. (e.g. 4j, my_function()j, or some_variable * j)

Arguments

  • input - The user’s desired tensor written in simplified language.

Returns

  • A 64-bit complex tensor implementing the user’s data.

Panics

  • If there is a missing closing bracket.
  • If the tensor does not start with an opening bracket or is not a scalar.
  • If a literal with suffix or prefix j is not a valid number.